"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const resvg_js_1 = require("@resvg/resvg-js");
const shiki_1 = require("shiki");
const shiki_renderer_svg_1 = require("shiki-renderer-svg");
class Graphite {
    constructor(code, lang, theme, options) {
        this.code = code;
        this.lang = lang;
        this.theme = theme;
        this.options = options;
        this.SVG = (0, shiki_1.getHighlighter)({ theme: this.theme ? this.theme : "github-dark" }).then(hl => {
            const token = hl.codeToThemedTokens(this.code, this.lang);
            return (0, shiki_renderer_svg_1.getSVGRenderer)({
                fontFamily: "Fira Code, Consolas, 'Courier New', monospace",
            }).then(svg => svg.renderToSVG(token, { bg: "#000" }));
        });
    }
    async svg() {
        return await this.SVG;
    }
    async png() {
        const svg = await this.SVG;
        const resvg = new resvg_js_1.Resvg(svg);
        const svgData = resvg.render();
        const pngBuffer = svgData.asPng();
        return pngBuffer;
    }
    async base64() {
        const svg = await this.SVG;
        const resvg = new resvg_js_1.Resvg(svg);
        const svgData = resvg.render();
        const base64 = svgData.asPng().toString("base64");
        return base64;
    }
}
exports.default = Graphite;
